==> bigloo3.1a.tar.gz: bigloo3.1a/runtime/Jlib/socket.java <==
/*=====================================================================*/
/*    serrano/prgm/project/bigloo/runtime/Jlib/socket.java             */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Tue Dec  5 10:53:03 2000                          */
/*    Last change :  Mon Jul 16 08:45:25 2007 (serrano)                */
/*    Copyright   :  2000-07 Manuel Serrano                            */
/*    -------------------------------------------------------------    */
/*    The Socket implementation for the JVM back-end.                  */
/*=====================================================================*/
package bigloo;

import java.io.*;
import java.net.*;

/*---------------------------------------------------------------------*/
/*    SOCKET ...                                                       */
/*---------------------------------------------------------------------*/
public abstract class socket extends obj {
   /*--- public fields ------------------------------------------------*/
   public obj input;
   public obj output;

   /*--- protected fields ---------------------------------------------*/
   protected boolean down = false;
   protected boolean closed = false;

   /*--- constructors -------------------------------------------------*/
   protected socket() {
      input = bigloo.foreign.BFALSE;
      output = bigloo.foreign.BFALSE;
   }

   /*--- protected methods --------------------------------------------*/
   protected static void socket_error( String s1, String s2, Object o ) {
      foreign.fail( s1, s2, o );
   }

   protected void set_socket_io_ports( Socket client_socket, boolean blocking )
      throws IOException {
      input = new input_socket_port( client_socket.getInputStream(), blocking );
      // CARE must be buffered !?
      output = new output_port( client_socket.getOutputStream() );
/*       input = new input_socket_port( new BufferedInputStream( client_socket.getInputStream() ), blocking ); */
/*       output = new output_port( new BufferedOutputStream( client_socket.getOutputStream() ) ); */
   }

   /*--- public methods -----------------------------------------------*/
   public boolean DOWNP() {
      return down;
   }

   public Object close()
      throws IOException {
      if (!closed) {
	 closed= true;
	 if (input instanceof input_port)
	    ((input_port)input).close();
	 if (output instanceof output_port)
	    ((output_port)output).close();
      }
      return bigloo.foreign.BUNSPEC;
   }

   /*--- public abstract methods --------------------------------------*/
   public abstract Object HOSTNAME();
   public abstract Object HOSTIP();
   public abstract Object shutdown( boolean  close_socket ) throws IOException;
   public abstract int PORT();
   public abstract byte[] local_addr();
}

==> bigloo3.2a-2.tar.gz: bigloo3.2a-2/runtime/Jlib/socket.java <==
/*=====================================================================*/
/*    serrano/prgm/project/bigloo/runtime/Jlib/socket.java             */
/*    -------------------------------------------------------------    */
/*    Author      :  Manuel Serrano                                    */
/*    Creation    :  Tue Dec  5 10:53:03 2000                          */
/*    Last change :  Mon Sep 22 15:11:22 2008 (serrano)                */
/*    Copyright   :  2000-08 Manuel Serrano                            */
/*    -------------------------------------------------------------    */
/*    The Socket implementation for the JVM back-end.                  */
/*=====================================================================*/
package bigloo;

import java.io.*;
import java.net.*;

/*---------------------------------------------------------------------*/
/*    SOCKET ...                                                       */
/*---------------------------------------------------------------------*/
public abstract class socket extends obj {
   /*--- static protect variables -------------------------------------*/
   protected static keyword tcp_nodelay = keyword.make_keyword( "TCP_NODELAY" );
   protected static keyword so_keepalive = keyword.make_keyword( "SO_KEEPALIVE" );
   protected static keyword so_oobinline = keyword.make_keyword( "SO_OOBINLINE" );
   protected static keyword so_rcvbuf = keyword.make_keyword( "SO_RCVBUF" );
   protected static keyword so_sndbuf = keyword.make_keyword( "SO_SNDBUF" );
   protected static keyword so_reuseaddr = keyword.make_keyword( "SO_REUSEADDR" );
   protected static keyword so_timeout = keyword.make_keyword( "SO_TIMEOUT" );
   
   /*--- public fields ------------------------------------------------*/
   public obj input;
   public obj output;

   /*--- protected fields ---------------------------------------------*/
   protected boolean down = false;
   protected boolean closed = false;

   /*--- constructors -------------------------------------------------*/
   protected socket() {
      input = bigloo.foreign.BFALSE;
      output = bigloo.foreign.BFALSE;
   }

   /*--- protected methods --------------------------------------------*/
   protected static void socket_error( String s1, String s2, Object o ) {
      foreign.fail( s1, s2, o );
   }

   protected void set_socket_io_ports( Socket client_socket,
				       byte[] inbuf,
				       byte[] outbuf )
      throws IOException {
      input = new input_socket_port( client_socket.getInputStream(), inbuf );
      // CARE must be buffered !?
      output = new output_port( client_socket.getOutputStream() );
/*       input = new input_socket_port( new BufferedInputStream( client_socket.getInputStream() ), blocking ); */
/*       output = new output_port( new BufferedOutputStream( client_socket.getOutputStream() ) ); */
   }

   /*--- public methods -----------------------------------------------*/
   public boolean DOWNP() {
      return down;
   }

   public Object close()
      throws IOException {
      if (!closed) {
	 closed= true;
	 if (input instanceof input_port)
	    ((input_port)input).close();
	 if (output instanceof output_port)
	    ((output_port)output).close();
      }
      return bigloo.foreign.BUNSPEC;
   }

   public Object getsockopt( keyword se ) throws IOException {
      return foreign.BUNSPEC;
   }
   
   public Object setsockopt( keyword se, Object val ) throws IOException {
      return foreign.BFALSE;
   }
      
   /*--- public abstract methods --------------------------------------*/
   public abstract Object HOSTNAME();
   public abstract Object HOSTIP();
   public abstract Object shutdown( boolean  close_socket ) throws IOException;
   public abstract int PORT();
   public abstract byte[] local_addr();
}
